==> v0.0.1.tar.gz: core/conf/types.go <==
package conf

type Base struct {
	Service        string `yaml:"Service"`        // 服务名称
	Port           int    `yaml:"Port"`           // 服务监听端口,0为自动随机端口
	Cache          string `yaml:"Cache"`          // REDIS缓存
	OnMicroService bool   `yaml:"OnMicroService"` // 是否启用微服务
	SecretKey      string `yaml:"SecretKey"`      // 服务秘钥
}

type DBConf struct {
	Driver string   `yaml:"Driver"` // 数据库驱动：mysql,sqlite,postgres,sqlserver,dm,kingbase
	Source []string `yaml:"Source"` // 数据库连接
}

type ApmConf struct {
	Name     string // APM服务名称
	Platform string `yaml:"Platform"` // APM平台：apm,skywalking
	Endpoint string `yaml:"Endpoint"` // APM服务接入地址
}

type EtcdConf struct {
	Endpoints []string    `yaml:"Endpoints"` // etcd服务接入地址
	Passwd    *PasswdConf `yaml:"Passwd"`    // etcd账号密码
	TLS       *TlsConf    `yaml:"TLS"`       // tls 安全连接
}

type PasswdConf struct {
	Account  string `yaml:"Account"`  // etcd账号
	Password string `yaml:"Password"` // etcd密码
}

type RpcConf struct {
	Key       string `yaml:"Key"`       // 微服务名称
	Endpoint  string `yaml:"Endpoint"`  // 服务接入地址
	SecretKey string `yaml:"SecretKey"` // 秘钥
}

type OssConf struct {
	Site            string `yaml:"Site"`            // oss站点HOST
	Endpoint        string `yaml:"Endpoint"`        // oss服务接入地址
	Region          string `yaml:"Region"`          // oss服务区域
	AccessKeyID     string `yaml:"AccessKeyId"`     // oss AccessKeyId
	AccessKeySecret string `yaml:"AccessKeySecret"` // oss AccessKeySecret
}

type MqConf struct {
	Endpoints []string `yaml:"Endpoints"` // MQ服务接入地址
	Space     string   `yaml:"Space"`     // MQ服务空间
}

type Runtime struct {
	Mode        string // 运行模式：dev,test,prod
	JwtKey      string // JWT密钥
	LicencePath string // Licence文件路径
}

type TlsConf struct {
	CaFile   string // CA文件路径
	CertFile string // 证书文件路径
	KeyFile  string // 密钥文件路径
}

==> v0.0.39.tar.gz: core/conf/types.go <==
package conf

type Base struct {
	Service        string `yaml:"Service"`   // 服务名称
	Port           string `yaml:"Port"`      // 服务监听端口,0为自动随机端口
	Cache          string `yaml:"Cache"`     // REDIS缓存
	SecretKey      string `yaml:"SecretKey"` // 服务秘钥
	BindIP         string `yaml:"BindIP"`    // 绑定IP
	Addr           string `yaml:"Addr"`
	OnMicroService bool   `yaml:"OnMicroService"`
}

type DBConf struct {
	Driver string   `yaml:"Driver"` // 数据库驱动：mysql,sqlite,postgres,sqlserver,dm,kingbase
	Source []string `yaml:"Source"` // 数据库连接
}

type MicroServiceConf struct {
	Enable    bool     `yaml:"Enable"` // 是否启用微服务
	Anonymous []string `yaml:"Anonymous"`
}

type GatewayConf struct {
	Enable bool `yaml:"Enable"` // 是否启用网关服务
	Port   int  `yaml:"Port"`   // 服务监听端口
}

type ApmConf struct {
	Name     string // APM服务名称
	Platform string `yaml:"Platform"` // APM平台：apm,skywalking
	Endpoint string `yaml:"Endpoint"` // APM服务接入地址
}

type EtcdConf struct {
	Endpoints []string    `yaml:"Endpoints"` // etcd服务接入地址
	Passwd    *PasswdConf `yaml:"Passwd"`    // etcd账号密码
	TLS       *TlsConf    `yaml:"TLS"`       // tls 安全连接
}

type PasswdConf struct {
	Account  string `yaml:"Account"`  // etcd账号
	Password string `yaml:"Password"` // etcd密码
}

type RpcConf struct {
	Key       string `yaml:"Key"`       // 微服务名称
	Endpoint  string `yaml:"Endpoint"`  // 服务接入地址
	SecretKey string `yaml:"SecretKey"` // 秘钥
}

type OssConf struct {
	Site            string `yaml:"Site"`            // oss站点HOST
	Endpoint        string `yaml:"Endpoint"`        // oss服务接入地址
	Region          string `yaml:"Region"`          // oss服务区域
	AccessKeyID     string `yaml:"AccessKeyId"`     // oss AccessKeyId
	AccessKeySecret string `yaml:"AccessKeySecret"` // oss AccessKeySecret
}

type MqConf struct {
	Endpoints []string `yaml:"Endpoints"` // MQ服务接入地址
	Space     string   `yaml:"Space"`     // MQ服务空间
}

type TlsConf struct {
	CaFile   string // CA文件路径
	CertFile string // 证书文件路径
	KeyFile  string // 密钥文件路径
}
